@@ -32,6 +32,9 @@ var LABEL = {
 };
 
 
+var objectId = 0;
+
+
 /**
  * Variants defined in protorpc/messages.py.
  */
@@ -76,6 +79,26 @@ function error(message) {
 }
 
 
+/**
+ * Display request errors in error panel.
+ * @param {object} XMLHttpRequest object.
+ */
+function handleRequestError(response) {
+    var contentType = response.getResponseHeader('content-type');
+    if (contentType == 'application/json') {
+        var response_error = $.parseJSON(response.responseText);
+        var error_message = response_error.error_message;
+        if (error.state == 'APPLICATION_ERROR' && error.error_name) {
+            var error_message = error_message + ' (' + error.error_name + ')';
+        }
+    } else {
+        error_message = '' + response.status + ': ' + response.statusText;
+    }
+
+    error(error_message);
+}
+
+
 /**
  * Send JSON RPC to remote method.
  * @param {string} path Path of service on originating server to send request.
@@ -83,13 +106,14 @@ function error(message) {
  * @param {Object} request Message to send as request.
  * @param {function} on_success Function to call upon successful request.
  */
-function sendRequest(path, method, request, on_success) {
+function sendRequest(path, method, request, onSuccess) {
   $.ajax({url: path + '.' + method,
           type: 'POST',
           contentType: 'application/json',
           data: $.toJSON(request),
           dataType: 'json',
-          success: on_success
+          success: onSuccess,
+          error: handleRequestError
          });
 }
 
@@ -243,7 +267,6 @@ function buildRepeatedForm(form) {
 function buildFieldForm(form, allowRepeated) {
   // All form fields are added to a row of a table.
   var inputData = $('<td>');
-  form.container.append(nameData);
 
   // Set name.
   if (allowRepeated) {
@@ -267,8 +290,10 @@ function buildFieldForm(form, allowRepeated) {
     var controlData = $('<td>');
     if (form.field.label != LABEL.REQUIRED && allowRepeated) {
         form.enabled = false;
-      var checkbox = $('<input type="checkbox">').appendTo(controlData);
-      var disableMessage = $('<i>Do not send</i>').appendTo(inputData);
+      var checkbox_id = 'checkbox-' + objectId++;
+      $('<label for="' + checkbox_id + '">Enabled</label>').appendTo(controlData);
+      var checkbox = $('<input id="' + checkbox_id + '" type="checkbox">').appendTo(controlData);
+      var disableMessage = $('<div>').appendTo(inputData);
       checkbox.change(toggleInput(checkbox, form, disableMessage));
     } else {
       buildIndividualForm(form);
@@ -299,7 +324,7 @@ function buildMessageForm(form, messageType) {
   if (messageType.fields) {
     $.each(messageType.fields, function(index, field) {
       var row = $('<tr>').appendTo(form.table);
-      fieldForm = new FormElement(field, row);
+      var fieldForm = new FormElement(field, row);
       fieldForm.parent = form;
       buildFieldForm(fieldForm, true);
       form.fields.push(fieldForm);
